module EasyReports
  class DatabaseMediator
    class DatabaseNotFoundError < StandardError; end

    attr_reader :connection, :db

    delegate :adapter, :username, :password, :host, :port, :name,
      to: :db

    def initialize(database_id)
      @db = set_database(database_id)
      @connection = establish_connection
    rescue => e
      Rails.logger.info "#{e.message}"
      raise DatabaseNotFoundError
    end

    def tables
      connection.tables
    end

    private

    def set_database(id)
      EasyReports::Database.find(id)
    end

    def establish_connection
      ::Sequel.connect(
        "#{adapter}://#{username}:#{password}@#{host}:#{port}/#{name}",
        :max_connections => db.pool,
        :logger => Logger.new('log/db.log'))
    end
  end
end
